@@ -1,6 +1,6 @@
 from typing import Optional, List, Any
 
-from StructNoSQL.middlewares.dynamodb.backend.dynamodb_core import Response
+from StructNoSQL.clients_middlewares.dynamodb.backend.dynamodb_core import Response
 from StructNoSQL.models import DatabasePathElement
 
 
@@ -19,7 +19,7 @@ class Query:
         self.index_name = index_name
         self._query_limit = None
 
-    def query_limit(self, limit: int):
+    def pagination_records_limit(self, limit: int):
         self._query_limit = limit
 
     def where(self) -> str:
